.. _other-implementations:

Other Implementations
*********************

* https://github.com/mafintosh/merkle-tree-stream
* https://github.com/datrs/merkle-tree-stream
* https://github.com/datcxx/merkle-tree-stream
